.. _github-stats-3-8-4:

GitHub statistics for 3.8.4 (Apr 03, 2024)
==========================================

GitHub statistics for 2023/09/15 (tag: v3.8.0) - 2024/04/03

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 3 issues and merged 27 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/89?closed=1>`__

The following 26 authors contributed 351 commits.

* 0taj
* Alec Vercruysse
* Alexander Volkov
* Antony Lee
* Anvi Verma
* Chiraag Balu
* David Gilbertson
* David Stansby
* dependabot[bot]
* Elliott Sales de Andrade
* Eric Firing
* Greg Lucas
* Gurudatta Shanbhag
* hannah
* James Salsman
* Jody Klymak
* Kyle Sunden
* lkkmpn
* Lucia Korpas
* Matthew Morrison
* Oscar Gustafsson
* Ruth Comer
* Samuel Diebolt
* Thomas A Caswell
* Tim Hoffmann
* wemi3

GitHub issues and pull requests:

Pull Requests (27):

* :ghpull:`28015`: Backport PR #27955 on branch v3.8.x (Add a draw during show for macos backend)
* :ghpull:`27993`: Unpin numpy 2, build against prerelease numpy in CIBW
* :ghpull:`27955`: Add a draw during show for macos backend
* :ghpull:`28001`: Backport PR #28000 on branch v3.8.x (Fix color sequence data for Set2 and Set3)
* :ghpull:`28000`: Fix color sequence data for Set2 and Set3
* :ghpull:`27990`: Backport PR #27988 on branch v3.8.x (gtk: Ensure pending draws are done before GTK draw)
* :ghpull:`27988`: gtk: Ensure pending draws are done before GTK draw
* :ghpull:`27986`: Backport PR #27985 on branch v3.8.x (TST: Remove superfluous chdir from tests)
* :ghpull:`27985`: TST: Remove superfluous chdir from tests
* :ghpull:`27976`: Backport PR #27975 on branch v3.8.x (DOC: Fix typo in ``ax.transData.inversed()``)
* :ghpull:`27934`: Backport PR #27933 on branch v3.8.x (Update "Created with" url in hand.svg)
* :ghpull:`27933`: Update "Created with" url in hand.svg
* :ghpull:`27926`: Backport PR #27875 on branch v3.8.x (macosx: Clean up single-shot timers correctly)
* :ghpull:`27925`: Backport PR #27921 on branch v3.8.x (Avoid modifying user input to Axes.bar)
* :ghpull:`27875`: macosx: Clean up single-shot timers correctly
* :ghpull:`27921`: Avoid modifying user input to Axes.bar
* :ghpull:`27903`: Merge 3.8.3-doc into 3.8.x
* :ghpull:`27889`: Backport PR #27888 on branch v3.8.x (DOC: fix stray release note entry)
* :ghpull:`27888`: DOC: fix stray release note entry
* :ghpull:`27849`: Backport PR #27754 on branch v3.8.x (fix quiver3d incorrect arrow colors)
* :ghpull:`27859`: Backport PR #27858 on branch v3.8.x (pin pytest)
* :ghpull:`27858`: pin pytest
* :ghpull:`27754`: fix quiver3d incorrect arrow colors
* :ghpull:`27847`: Backport PR #27846 on branch v3.8.x (Make example in legend_elements doc more generalisable)
* :ghpull:`27846`: Make example in legend_elements doc more generalisable
* :ghpull:`27802`: Backport PR #27794 on branch v3.8.x (Remove old reference to 72 DPI in figure_size_units.py)
* :ghpull:`27794`: Remove old reference to 72 DPI in figure_size_units.py

Issues (3):

* :ghissue:`27953`: [Bug]: Pyplot can no longer set axes properties
* :ghissue:`11759`: The color of the 3D arrow head does not match that of the arrow body
* :ghissue:`27826`: [Bug]: Unexpected behavior of scatter.legend_elements
